Documentation
¶
Index ¶
Constants ¶
const ( // DefaultBackupRestoreTLSEnabled defines the default TLS state of the application DefaultBackupRestoreTLSEnabled = false // DefaultBackupRestoreHostPort defines the default sidecar host and port DefaultBackupRestoreHostPort = ":8080" // DefaultExitCodeFilePath defines the default file path for the file that stores the exit code of the previous run DefaultExitCodeFilePath = "/var/etcd/data/exit_code" // ValidationMarkerFilePath defines the file path to the legacy file that was used to record exit code of the previous run ValidationMarkerFilePath = "/var/etcd/data/validation_marker" // DefaultLogLevel defines the default log level for any zap loggers created DefaultLogLevel = zapcore.InfoLevel )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type BackupRestoreConfig ¶
BackupRestoreConfig defines parameters needed to interact with the backup-restore container
func (*BackupRestoreConfig) GetBaseAddress ¶
func (c *BackupRestoreConfig) GetBaseAddress() string
GetBaseAddress returns the complete address of the backup restore container.
func (*BackupRestoreConfig) GetHost ¶
func (c *BackupRestoreConfig) GetHost() string
GetHost extracts the backup-restore server host from host-port string.
func (*BackupRestoreConfig) Validate ¶
func (c *BackupRestoreConfig) Validate() (err error)
Validate validates backup-restore configuration.
type Config ¶
type Config struct {
// BackupRestore is the configuration to interact with the backup-restore container.
BackupRestore BackupRestoreConfig
// EtcdClientTLS is the TLS configuration required to configure a client when TLS is enabled when interacting with the embedded etcd.
EtcdClientTLS EtcdClientTLSConfig
// EtcdClientPort is port when talking to etcd.
EtcdClientPort int
// EtcdWrapperPort is the server port for etcd-wrapper.
EtcdWrapperPort int
}
Config holds the application configuration for etcd-wrapper.
type EtcdClientTLSConfig ¶
type EtcdClientTLSConfig struct {
// ServerName is the name of the etcd server. It should be ensured that the name used
// should also be specified as one of the name(s) in the subject-alternate names in the etcd server certificate.
ServerName string
// CertPath is the path to the client certificate
CertPath string
// KeyPath is the path to the client key
KeyPath string
}
EtcdClientTLSConfig holds the TLS configuration to configure a etcd client.
Click to show internal directories.
Click to hide internal directories.